# CreateWorkflowExecutionSpecDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**execution_id** | **str** |  | 
**parameters** | [**WorkflowTemplateParameters**](WorkflowTemplateParameters.md) |  | [optional] 
**definition** | [**WorkflowTemplateDefinition**](WorkflowTemplateDefinition.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

